@@ -29,7 +29,6 @@ use threads ('yield',
 use threads::shared;
 my $semaphorus : shared = 0;
 my $command : shared = "sleep";
-my $ZenStyle = 1 ;
 
 # Internationalization
 setlocale(LC_ALL, "");
@@ -41,7 +40,7 @@ textdomain("netpkg");
 
 use constant CATEGORY => 0;
 use constant AVAILABLE_PKG => 1;
-use constant SORTSTRING => 2;
+use constant UID => 2;
 use constant SIZE_COMPRESSED => 3;
 use constant SIZE_UNCOMPRESSED => 4;
 use constant DEPENDENCIES => 5;
@@ -205,102 +204,14 @@ sub BuildDB {
 			$package="$1"; 
 			$package =~ /^(.*)-([^-]*)-[^-]*-([^-]*).t[glx]z$/;
 			$soft="$1"; 
+			chomp $1;
 			@{$db{$soft}}[AVAILABLE_PKG] = "$package";	
 			@{$db{$soft}}[AVAILABLE_VERSION] = "$2";
 			@{$db{$soft}}[AVAILABLE_BUILD] = "$3";		
 			next;
 		}
 		if ($_ =~ /PACKAGE LOCATION:\s*\.?\/?([^\s]*)\s*$/) { 
-			@{$db{$soft}}[PATH] = "$1";	
-
-			if ( $ZenStyle = 1 ) {
-				if ( 
-				@{$db{$soft}}[PATH] =~ /^l$/ || 
-				@{$db{$soft}}[PATH] =~ /.*\/l$/ 
-				) {
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Runtime libraries"));
-					@{$db{$soft}}[CATEGORY_ICON] = "gnome-other";
-				}elsif ( 
-				@{$db{$soft}}[PATH] =~ /^d$/ ||
-				@{$db{$soft}}[PATH] =~ /.*\/d$/ 
-				) {
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Development libraries"));
-					@{$db{$soft}}[CATEGORY_ICON] = "development";
-				}elsif ( 
-				@{$db{$soft}}[PATH] =~ /^x$/ ||
-				@{$db{$soft}}[PATH] =~ /.*\/x$/ 
-				) {
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Xorg"));
-					@{$db{$soft}}[CATEGORY_ICON] = "xorg";
-				}elsif ( 
-				@{$db{$soft}}[PATH] =~ /^ap$/ ||
-				@{$db{$soft}}[PATH] =~ /.*\/ap$/
-				) {
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Console Applications"));
-					@{$db{$soft}}[CATEGORY_ICON] = "utilities-terminal";
-				}elsif ( 
-				@{$db{$soft}}[PATH] =~ /^xap$/ ||
-				@{$db{$soft}}[PATH] =~ /.*\/xap$/
-				) {
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Graphical Applications"));
-					@{$db{$soft}}[CATEGORY_ICON] = "applications-graphics";
-				}elsif ( 
-				@{$db{$soft}}[PATH] =~ /.*\/g$/ 
-				) {
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Gnome Desktop"));
-					@{$db{$soft}}[CATEGORY_ICON] = "gnome-logo";
-				}elsif ( 
-				@{$db{$soft}}[PATH] =~ /.*\/kde$/ 
-				) {
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("KDE Desktop"));
-					@{$db{$soft}}[CATEGORY_ICON] = "konqueror";
-				}elsif ( 
-				@{$db{$soft}}[PATH] =~ /^a$/ || 
-				@{$db{$soft}}[PATH] =~ /.*\/a$/ 
-				) {
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("System"));
-					@{$db{$soft}}[CATEGORY_ICON] = "applications-system";
-				}elsif ( 
-				@{$db{$soft}}[PATH] =~ /^locale$/ || 
-				@{$db{$soft}}[PATH] =~ /.*\/locale$/ 
-				) {
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Localization"));
-					@{$db{$soft}}[CATEGORY_ICON] = "preferences-desktop-locale";
-				}elsif ( 
-				@{$db{$soft}}[PATH] =~ /^games$/ || 
-				@{$db{$soft}}[PATH] =~ /.*\/games$/ 
-				) {
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Games"));
-					@{$db{$soft}}[CATEGORY_ICON] = "applications-games";
-				}elsif ( 
-				@{$db{$soft}}[PATH] =~ /^n$/ || 
-				@{$db{$soft}}[PATH] =~ /.*\/n$/ ||
-				@{$db{$soft}}[PATH] =~ /^s$/ || 
-				@{$db{$soft}}[PATH] =~ /.*\/s$/ 
-				) {
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Network"));
-					@{$db{$soft}}[CATEGORY_ICON] = "applications-internet";
-				}else{
-					@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Misc"));
-					@{$db{$soft}}[CATEGORY_ICON] = "applications-other";
-				}
-				
-				#if ( @{$db{$soft}}[PATH] =~ /^extra.*/ ) {
-				#	@{$db{$soft}}[CATEGORY] = "Extra ".@{$db{$soft}}[CATEGORY] ;
-				#}
-				
-				
-				@{$db{$soft}}[SORTSTRING] = @{$db{$soft}}[CATEGORY]."/".$package;
-				
-			}else{
-				@{$db{$soft}}[CATEGORY] = @{$db{$soft}}[PATH] ;
-				if ( @{$db{$soft}}[PATH] =~ /^extra.*/ ) {
-					@{$db{$soft}}[SORTSTRING] = "y".@{$db{$soft}}[CATEGORY]."/".$package;
-				}else{
-					@{$db{$soft}}[SORTSTRING] = @{$db{$soft}}[CATEGORY]."/".$package;
-				}
-			}	
-			
+			@{$db{$soft}}[PATH] = "$1";		
 			next;
 		}	
 		if ($_ =~ /PACKAGE SIZE \(c.*:\s*(.*)\s*$/) { 
@@ -356,6 +267,94 @@ sub BuildDB {
 	return \%db;
 }
 
+####################################################################
+# Will set categories according to the origin of package
+sub SetCategories {
+	my $self = shift; 
+	my %db = %{$_[0]};
+	my $soft;
+	for $soft ( keys %db ) {
+		if ( 
+		@{$db{$soft}}[PATH] =~ /^l$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/l$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Runtime libraries"));
+			@{$db{$soft}}[CATEGORY_ICON] = "gnome-other";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^d$/ ||
+		@{$db{$soft}}[PATH] =~ /.*\/d$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Development libraries"));
+			@{$db{$soft}}[CATEGORY_ICON] = "development";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^x$/ ||
+		@{$db{$soft}}[PATH] =~ /.*\/x$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Xorg"));
+			@{$db{$soft}}[CATEGORY_ICON] = "xorg";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^ap$/ ||
+		@{$db{$soft}}[PATH] =~ /.*\/ap$/
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Console Applications"));
+			@{$db{$soft}}[CATEGORY_ICON] = "utilities-terminal";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^xap$/ ||
+		@{$db{$soft}}[PATH] =~ /.*\/xap$/
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Graphical Applications"));
+			@{$db{$soft}}[CATEGORY_ICON] = "applications-graphics";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /.*\/g$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Gnome Desktop"));
+			@{$db{$soft}}[CATEGORY_ICON] = "gnome-logo";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /.*\/kde$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("KDE Desktop"));
+			@{$db{$soft}}[CATEGORY_ICON] = "konqueror";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^a$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/a$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("System"));
+			@{$db{$soft}}[CATEGORY_ICON] = "applications-system";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^locale$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/locale$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Localization"));
+			@{$db{$soft}}[CATEGORY_ICON] = "preferences-desktop-locale";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^games$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/games$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Games"));
+			@{$db{$soft}}[CATEGORY_ICON] = "applications-games";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^patches$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/patches$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Patches"));
+			@{$db{$soft}}[CATEGORY_ICON] = "administration";
+		}elsif ( 
+		@{$db{$soft}}[PATH] =~ /^n$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/n$/ ||
+		@{$db{$soft}}[PATH] =~ /^s$/ || 
+		@{$db{$soft}}[PATH] =~ /.*\/s$/ 
+		) {
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Network"));
+			@{$db{$soft}}[CATEGORY_ICON] = "applications-internet";
+		}else{
+			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Misc"));
+			@{$db{$soft}}[CATEGORY_ICON] = "applications-other";
+		}
+			
+		@{$db{$soft}}[UID] = @{$db{$soft}}[CATEGORY].$soft.@{$db{$soft}}[AVAILABLE_VERSION].@{$db{$soft}}[AVAILABLE_BUILD].@{$db{$soft}}[INSTALLED_VERSION].@{$db{$soft}}[INSTALLED_BUILD];							
+	}
+	#return \%db;
+}
 
 ####################################################################
 # Will check installed packages to fill %db related fields
@@ -396,9 +395,9 @@ sub CheckInstalledPkgs {
 		}else{
 			@{$db{$soft}}[STATUS] = STATUS_OK;
 			@{$db{$soft}}[AVAILABLE_VERSION] = "not on mirror";	
-			@{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Local"));	
-			@{$db{$soft}}[CATEGORY_ICON] = "folder";
-			@{$db{$soft}}[SORTSTRING] = "z"."/".@{$db{$soft}}[CATEGORY]."/".$package;
+			# @{$db{$soft}}[CATEGORY] = decode('utf8',gettext("Local"));	
+			# @{$db{$soft}}[CATEGORY_ICON] = "folder";
+			
 			
 			seek(FH, 0, 0);
 			while(<FH>) {
@@ -415,12 +414,12 @@ sub CheckInstalledPkgs {
 					my $regex = '^'.$self->{Local_repository}.'/(.*)/[^/]*.t[glx]z\s*$';
 					$regex =~ s/\//\\\//g ;
 					if ($fullpath =~ /$regex/ ) {
-						@{$db{$soft}}[PATH] = "$1";
+						@{$db{$soft}}[PATH] = "$1";			
 					}else{
 						@{$db{$soft}}[PATH] = "local";
 					}
 					next;							
-				}					
+				}	
 				
 				# @{$db{$soft}}[DESCRIPTION] = "" if ( undef @{$db{$soft}}[DESCRIPTION] ) ;	
 				while ($_ =~ /\Q${soft}\E:(.*)/) {
